@@ -38,10 +38,14 @@ def add_define(name, value = nil)
   end
 end
 
-if !Gem.win_platform? && RUBY_PLATFORM !~ /(darwin|openbsd)/
+def windows?
+  RbConfig::CONFIG['host_os'] =~ /mswin|mingw/
+end
+
+if !windows? && RUBY_PLATFORM !~ /(darwin|openbsd)/
   $LDFLAGS += " -lrt" # for clock_gettime
 end
-add_define("RUBY_VERSION", RUBY_VERSION.gsub('.', ''))
+add_define("RUBY_PROF_RUBY_VERSION", RUBY_VERSION.split('.')[0..2].inject(0){|v,d| v*100+d.to_i})
 
 # for ruby 1.9, determine whether threads inherit trace flags (latest 1.9.2 and later should work correctly)
 if RUBY_VERSION > "1.9"
@@ -51,7 +55,7 @@ if RUBY_VERSION > "1.9"
   Thread.new{1}.join
   set_trace_func nil
   if threads.size < 2
-    # if we end up here, ruby does not automatically active tracing in spawned threads
+    # if we end up here, ruby does not automatically activate tracing in spawned threads
     STDERR.puts("Ruby #{RUBY_VERSION} does not activate tracing in spawned threads. Consider upgrading.")
     exit(1)
   end
